@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: chora/browse.php,v 1.5.4.3 2005/06/02 11:37:36 selsky Exp $
+ * $Horde: chora/browse.php,v 1.5.4.6 2007/02/23 03:58:53 selsky Exp $
  *
- * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 1999-2005 Charles Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2007 Charles Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -240,5 +240,5 @@ if ($atdir) {
     require CHORA_TEMPLATES . '/log/request.inc';
     require $registry->get('templates', 'horde') . '/common-footer.inc';
 } else {
-    Chora::fatal('404 Not Found', "$where: no such file or directory");
+    Chora::fatal("$where: no such file or directory");
 }
