@@ -1,11 +1,11 @@
 <?php
 /**
- * $Horde: chora/cvsgraph.php,v 1.15.8.1 2005/01/03 12:25:30 jan Exp $
+ * $Horde: chora/cvsgraph.php,v 1.15.8.4 2007/02/23 03:58:53 selsky Exp $
  *
  * Wrapper for CVSGraph.
  *
- * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
- * Copyright 1999-2005 Charles Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2007 Anil Madhavapeddy <anil@recoil.org>
+ * Copyright 1999-2007 Charles Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -83,5 +83,5 @@ if (@is_file($fullname . ',v')) {
         require $registry->get('templates', 'horde') . '/common-footer.inc';
     }
 } else {
-    Chora::fatal('404 Not Found', "$where: no such file or directory");
+    Chora::fatal("$where: no such file or directory");
 }
