@@ -2,7 +2,7 @@
 /**
  * Chora Base Class.
  *
- * $Horde: chora/lib/Chora.php,v 1.72.6.3 2005/10/11 21:13:14 jan Exp $
+ * $Horde: chora/lib/Chora.php,v 1.72.6.7 2007/02/23 03:58:53 selsky Exp $
  *
  * @author  Anil Madhavapeddy <avsm@horde.org>
  * @package Chora
@@ -111,7 +111,7 @@ class Chora {
         }
 
         if (!isset($sourceroots[$acts['rt']])) {
-            Chora::fatal(404, 'Malformed URL');
+            Chora::fatal('Malformed URL');
         }
 
         $sourcerootopts = $sourceroots[$acts['rt']];
@@ -201,7 +201,7 @@ class Chora {
             }
             $wherePath = str_replace('//', '/', $wherePath);
             if (!empty($dir) && ($dir != 'Attic')) {
-                $bar .= '/ <a href="' . Chora::url('', $wherePath) . '">'. Text::htmlallspaces($dir) . '</a>';
+                $bar .= '/ <a href="' . Chora::url('', $wherePath) . '">'. Text::htmlallspaces($dir) . '</a> ';
             }
         }
         return $bar;
